@@ -38,7 +38,7 @@ click.rich_click.OPTION_GROUPS = {
                 "--use-conda",
                 "--singularity_cache",
                 "--singularity_pull_docker_container",
-                "--force-rebuild",
+                "--force_rebuild",
                 "--max_retry",
             ],
         },
@@ -139,9 +139,15 @@ def parse_workflows(bactopia_path, include_merlin=False, build_all=False):
         if "path" in workflows[wf]:
             modules[wf] = True
 
-        if include_merlin and wf == "bactopia":
-            for module in workflows["merlin"]["modules"]:
+        if wf == "bactopia" or wf == "staphopia":
+            # Build Prokka and Bakta
+            modules["prokka"] = True
+            for module in workflows["bakta"]["modules"]:
                 modules[module] = True
+            # Install Merlin tools
+            if include_merlin:
+                for module in workflows["merlin"]["modules"]:
+                    modules[module] = True
 
         for module in modules:
             final_workflows[wf][module] = parse_module(
@@ -358,7 +364,7 @@ def build_conda_env(
     success = False
     while not success:
         result = execute(
-            f"{program} create -y -p {conda_path} -c conda-forge -c bioconda --force {conda_env}",
+            f"rm -rf {conda_path} && {program} create -y -p {conda_path} -c conda-forge -c bioconda {conda_env}",
             allow_fail=allow_fail,
         )
         if not result:
@@ -368,7 +374,7 @@ def build_conda_env(
             logging.error(
                 "Error creating Conda environment, retrying after short sleep."
             )
-            time.sleep(30 * retry)
+            time.sleep(10 * retry)
         else:
             success = True
     return success
@@ -386,7 +392,7 @@ def docker_pull(container, max_retry=5):
                 allow_fail = True
             retry += 1
             logging.error("Error pulling container, retrying after short sleep.")
-            time.sleep(30 * retry)
+            time.sleep(10 * retry)
         else:
             success = True
     return success
@@ -412,7 +418,7 @@ def build_singularity_image(image, pull, max_retry=5, force=False, use_build=Fal
                 allow_fail = True
             retry += 1
             logging.error("Error creating image, retrying after short sleep.")
-            time.sleep(30 * retry)
+            time.sleep(10 * retry)
         else:
             success = True
     return success
@@ -477,7 +483,7 @@ def build_singularity_image(image, pull, max_retry=5, force=False, use_build=Fal
     help="Force conversion of Docker containers, instead downloading Singularity images directly",
 )
 @click.option(
-    "--force-rebuild",
+    "--force_rebuild",
     is_flag=True,
     help="Force overwrite of existing pre-built environments.",
 )
